@@ -128,7 +128,7 @@ class Dataset(BaseDataset):
 
     data_kinds = {DataKind.FILE, DataKind.MMAP_FILE, DataKind.MEM_SEQ}
 
-    def __init__(self, data, filename='', kind=DataKind.MEM_SEQ, transform: Optional[Callable] = None):
+    def __init__(self, data, kind=DataKind.MEM_SEQ, transform: Optional[Callable] = None, filename=None):
         """
 
         Args:
